#!/usr/bin/perl
use utf8;
binmode stdin,":utf8";
binmode stdout,":utf8";

while (<>) {
s/لله/LLh/g;
s/لِله/LiLh/g;
s/لِّله/L+iLh/g;
s/أ/'a/g;
s/إ/'i/g;
s/ؤ/'u/g;
s/ىٔ/'I/g;
s/هٔ/e/g;
s/آ/'A/g;
s/ء/|/g;
s/ٱ/A*/g;
s/آ/'A/g;
s/أ/'a/g;
s/ؤ/'u/g;
s/إ/'i/g;
s/ئ/'I/g;
s/ا/A/g;
s/ب/b/g;
s/ة/t*/g;
s/ت/t/g;
s/ث/c/g;
s/ج/j/g;
s/ح/H/g;
s/خ/x/g;
s/د/d/g;
s/ذ/d•/g;
s/ر/r/g;
s/ز/z/g;
s/س/s/g;
s/ش/s•/g;
s/ص/S/g;
s/ض/D/g;
s/ط/T/g;
s/ظ/Z/g;
s/ع/`/g;
s/غ/R/g;
s/ف/f/g;
s/ق/q/g;
s/ك/k/g;
s/ل/l/g;
s/م/m/g;
s/ن/n/g;
s/ه/h/g;
s/و/U/g;
s/ى/I/g;
s/ي/Y/g;
s/پ/p/g;
s/گ/g/g;
s/چ/C/g;
s/ۀ/e/g;
s/ژ/J/g;
s/ڤ/v/g;
s/ٮ/'b/g;
s/ں/'n/g;
s/ڡ/'f/g;
s/ٯ/'q/g;
s/ً/aN/g;
s/ٌ/uN/g;
s/ٍ/iN/g;
s/َ/a/g;
s/ُ/u/g;
s/ِ/i/g;
s/ّ/+/g;
s/ْ/o/g;
s/ٰ/a*/g;
s/ٓ/a**/g;
s/،/,/g;
s/؟/?/g;
s/؛/;/g;
tr/٠١٢٣٤٥٦٧٨٩٪/0123456789%/;
s/‍/-/g;
s/ـ/--/g;
s/([tds])h/\1-h/g;
s/•/h/g;
print;
}